/**
 * 模型接口(模型驱动)
 */
interface IModel {
    __props: Map<string, IModelCfg>;
}
/**
 * 模型配置接口
 */
interface IModelCfg {
    /**
     * 数据类型
     */
    type: string;
    /**
     * 校验器 {name:参数数组}
     */
    validators: object;
}
/**
 * 基础模型
 */
declare class BaseModel {
    /**
     * 实际使用props
     */
    private __props;
    /**
     * 转换和验证，返回数据类型或验证不正确的属性消息集合
     * @param notTransform  是否不进行数据格式转换，默认false
     */
    __handle(notTransform?: boolean): object;
    /**
     * 验证
     * @param name  属性名
     * @returns     null或字符串(表示验证异常)
     */
    private __validate;
    /**
     * 数据格式转换
     * @param name  属性名
     * @returns     true 转换成功 false转换失败
     */
    private __transform;
    /**
     * 设置校验器
     * @param name          属性名
     * @param validators    验证器
     */
    __setValidator(name: string, validators: object): void;
    /**
     * 设置数据类型
     * @param name      属性名
     * @param type      属性类型
     */
    __setType(name: string, type: string): void;
    /**
     * 给属性增加指定校验器
     * @param name              属性名
     * @param validatorName     校验器名
     * @param params            校验参数
     */
    __addValidator(name: string, validatorName: string, params?: []): void;
    /**
     * 初始化prop map
     */
    private __initPropMap;
}
export { IModel, BaseModel };
